@@ -1,7 +1,7 @@
 /*
  * const - constant number storage module
  *
- * Copyright (C) 1999-2004  David I. Bell
+ * Copyright (C) 1999-2007  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,8 +17,8 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
  *
- * @(#) $Revision: 29.4 $
- * @(#) $Id: const.c,v 29.4 2004/02/23 14:04:01 chongo Exp $
+ * @(#) $Revision: 29.5 $
+ * @(#) $Id: const.c,v 29.5 2007/02/11 10:19:14 chongo Exp $
  * @(#) $Source: /usr/local/src/cmd/calc/RCS/const.c,v $
  *
  * Under source code control:	1990/02/15 01:48:14
@@ -34,9 +34,9 @@
 
 #define CONSTALLOCSIZE 400	/* number of constants to allocate */
 
-static unsigned long constcount;/* number of constants defined */
-static long constavail;		/* number of constants available */
-static NUMBER **consttable;	/* table of constants */
+STATIC unsigned long constcount;/* number of constants defined */
+STATIC long constavail;		/* number of constants available */
+STATIC NUMBER **consttable;	/* table of constants */
 
 
 void
