@@ -1,7 +1,7 @@
 /*
  * hash - one-way hash routines
  *
- * Copyright (C) 1999-2006  Landon Curt Noll
+ * Copyright (C) 1999-2007  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,8 +17,8 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
  *
- * @(#) $Revision: 29.10 $
- * @(#) $Id: hash.c,v 29.10 2006/06/20 10:25:45 chongo Exp $
+ * @(#) $Revision: 29.11 $
+ * @(#) $Id: hash.c,v 29.11 2007/02/11 10:19:14 chongo Exp $
  * @(#) $Source: /usr/local/src/cmd/calc/RCS/hash.c,v $
  *
  * Under source code control:	1995/11/23 05:13:11
@@ -43,9 +43,9 @@
 /*
  * external hash_setup functions
  */
-extern void shs_init_state(HASH*);
-extern void shs1_init_state(HASH*);
-extern void MD5_init_state(HASH*);
+E_FUNC void shs_init_state(HASH*);
+E_FUNC void shs1_init_state(HASH*);
+E_FUNC void MD5_init_state(HASH*);
 
 
 /*
@@ -60,7 +60,7 @@ extern void MD5_init_state(HASH*);
 /*
  * hash_setup - setup the hash state for a given hash
  */
-static struct hash_setup {
+STATIC struct hash_setup {
 	int type;		/* hash type (see XYZ_HASH_TYPE below) */
 	void (*init_state)(HASH*);	/* initialize a hash state */
 } htbl[] = {
