@@ -1,7 +1,7 @@
 /*
  * lib_calc - calc link library initialization and shutdown routines
  *
- * Copyright (C) 1999-2006  Landon Curt Noll
+ * Copyright (C) 1999-2007  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,8 +17,8 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
  *
- * @(#) $Revision: 29.14 $
- * @(#) $Id: lib_calc.c,v 29.14 2006/05/21 07:28:54 chongo Exp $
+ * @(#) $Revision: 29.16 $
+ * @(#) $Id: lib_calc.c,v 29.16 2007/02/18 14:24:56 chongo Exp $
  * @(#) $Source: /usr/local/src/cmd/calc/RCS/lib_calc.c,v $
  *
  * Under source code control:	1996/06/17 18:06:19
@@ -37,6 +37,7 @@
 # include <pwd.h>
 #endif
 
+#include "lib_calc.h"
 #include "calc.h"
 #include "zmath.h"
 #include "zrandom.h"
@@ -98,8 +99,8 @@ typedef struct {int fd;} ttystruct;
 #if !defined(HAVE_UID_T) && !defined(_UID_T)
 typedef unsigned short uid_t;
 #endif
-extern char *getenv();
-extern uid_t geteuid();
+E_FUNC char *getenv();
+E_FUNC uid_t geteuid();
 #endif
 
 
@@ -109,7 +110,6 @@ extern uid_t geteuid();
 int use_old_std = FALSE;	/* TRUE => use old classic configuration */
 int abortlevel;			/* current level of aborts */
 BOOL inputwait;			/* TRUE if in a terminal input wait */
-jmp_buf jmpbuf;			/* for errors */
 char *program = "calc";		/* our name */
 char *base_name = "calc";	/* basename of our name */
 char cmdbuf[MAXCMD+1+1+1];	/* command line expression + "\n\0" + guard */
@@ -148,9 +148,30 @@ char *shell = NULL;		/* $SHELL or default */
 int stdin_tty = FALSE;		/* TRUE if stdin is a tty */
 int havecommands = FALSE;	/* TRUE if have one or more cmd args */
 long stoponerror = 0;		/* >0 => stop, <0 => continue, ==0 => use -c */
-int post_init = FALSE;		/* TRUE setjmp for math_error is ready */
 BOOL abort_now = FALSE;		/* TRUE => go interactive now, if permitted */
 
+/* non-zero => calc_scanerr_jmpbuf ready */
+int calc_use_scanerr_jmpbuf = 0;
+/* for scan and parse errors */
+jmp_buf calc_scanerr_jmpbuf;
+
+/* non-zero => use calc_use_matherr_jmpbuf */
+int calc_use_matherr_jmpbuf = 0;
+/* math_error() control jump point when calc_use_matherr_jmpbuf != 0 */
+jmp_buf calc_matherr_jmpbuf;
+
+/* last calc error message, also parse/scan errors use this buffer */
+char calc_err_msg[MAXERROR+1];
+/* 0 ==> do not print parse/scan errors */
+int calc_print_scanerr_msg = 1;
+
+/* last parse/scan warning message */
+char calc_warn_msg[MAXERROR+1];
+/* 0 ==> do not print parse/scan warnings */
+int calc_print_scanwarn_msg = 1;
+/* number of parse/scan warnings found */
+unsigned long calc_warn_cnt = 0;
+
 int argc_value = 0;		/* count of argv[] strings for argv() builtin */
 char **argv_value = NULL;	/* argv[] strings for argv() builtin */
 
@@ -167,23 +188,24 @@ char *user_debug = NULL;	/* !=NULL => value of config("user_debug") */
 /*
  * initialization functions
  */
-extern void math_setfp(FILE *fp);
-extern void file_init(void);
-extern void zio_init(void);
-extern void initialize(void);
-extern void reinitialize(void);
+E_FUNC void math_setfp(FILE *fp);
+E_FUNC void file_init(void);
+E_FUNC void zio_init(void);
+E_FUNC void initialize(void);
+E_FUNC void reinitialize(void);
 
 
 /*
  * static declarations
  */
-static int init_done = 0;		/* 1 => we already initialized */
-static int *fd_setup = NULL;		/* fd's setup for interaction or -1 */
-static int fd_setup_len = 0;		/* number of fd's in fd_setup */
-static ttystruct *fd_orig = NULL;	/* fd original state */
-static ttystruct *fd_cur = NULL;	/* fd current state */
-static void initenv(void);		/* setup calc environment */
-static int find_tty_state(int fd);	/* find slot for saved tty state */
+STATIC int init_done = 0;		/* 1 => we already initialized */
+STATIC int *fd_setup = NULL;		/* fd's setup for interaction or -1 */
+STATIC int fd_setup_len = 0;		/* number of fd's in fd_setup */
+STATIC ttystruct *fd_orig = NULL;	/* fd original state */
+STATIC ttystruct *fd_cur = NULL;	/* fd current state */
+S_FUNC void initenv(void);		/* setup calc environment */
+S_FUNC int find_tty_state(int fd);	/* find slot for saved tty state */
+STATIC BOOL initialized = FALSE;	/* TRUE => initialize() has been run */
 
 
 /*
@@ -304,6 +326,13 @@ libcalc_call_me_first(void)
 void
 initialize(void)
 {
+	/*
+	 * firewall
+	 */
+	if (initialized) {
+		return;
+	}
+
 	/*
 	 * ZVALUE io initialization
 	 */
@@ -340,6 +369,11 @@ initialize(void)
 	math_setmode(MODE_INITIAL);
 	math_setdigits(DISPLAY_DEFAULT);
 	conf->maxprint = MAXPRINT_DEFAULT;
+
+	/*
+	 * note that we are done
+	 */
+	initialized = TRUE;
 }
 
 
@@ -394,7 +428,7 @@ cvmalloc_error(char *message)
  * use a default value. If $HOME does not exist, or is empty, use the home
  * directory information from the password file.
  */
-static void
+S_FUNC void
 initenv(void)
 {
 #if !defined(_WIN32)
@@ -597,7 +631,7 @@ calc_strdup(CONST char *s1)
  * Returns:
  *	indx	The index into fd_setup[], fd_orig[] and fd_cur[] to use or -1
  */
-static int
+S_FUNC int
 find_tty_state(int fd)
 {
 	int *new_fd_setup;		/* new fd_setup array */
