@@ -1,7 +1,7 @@
 /*
  * token - read input file characters into tokens
  *
- * Copyright (C) 1999  David I. Bell and Ernest Bowen
+ * Copyright (C) 1999-2007  David I. Bell and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -19,8 +19,8 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
  *
- * @(#) $Revision: 29.10 $
- * @(#) $Id: token.c,v 29.10 2006/06/24 18:43:05 chongo Exp $
+ * @(#) $Revision: 29.12 $
+ * @(#) $Id: token.c,v 29.12 2007/02/18 14:24:56 chongo Exp $
  * @(#) $Source: /usr/local/src/cmd/calc/RCS/token.c,v $
  *
  * Under source code control:	1990/02/15 01:48:25
@@ -35,9 +35,9 @@
 
 #include "calc.h"
 #include "token.h"
-#include "string.h"
+#include "str.h"
 #include "args.h"
-#include "math_error.h"
+#include "lib_calc.h"
 
 
 #define isletter(ch)	((((ch) >= 'a') && ((ch) <= 'z')) || \
@@ -52,7 +52,7 @@
 /*
  * Current token.
  */
-static struct {
+STATIC struct {
 	short t_type;		/* type of token */
 	char *t_sym;		/* symbol name */
 	long t_strindex;	/* index of string value */
@@ -60,12 +60,12 @@ static struct {
 } curtoken;
 
 
-static BOOL rescan;		/* TRUE to reread current token */
-static BOOL newlines;		/* TRUE to return newlines as tokens */
-static BOOL allsyms;		/* TRUE if always want a symbol token */
-static STRINGHEAD strings;	/* list of constant strings */
-static char *numbuf;		/* buffer for numeric tokens */
-static long numbufsize;		/* current size of numeric buffer */
+STATIC BOOL rescan;		/* TRUE to reread current token */
+STATIC BOOL newlines;		/* TRUE to return newlines as tokens */
+STATIC BOOL allsyms;		/* TRUE if always want a symbol token */
+STATIC STRINGHEAD strings;	/* list of constant strings */
+STATIC char *numbuf;		/* buffer for numeric tokens */
+STATIC long numbufsize;		/* current size of numeric buffer */
 
 long errorcount = 0;			/* number of compilation errors */
 
@@ -78,7 +78,7 @@ struct keyword {
 	int k_token;	/* token number */
 };
 
-static struct keyword keywords[] = {
+STATIC struct keyword keywords[] = {
 	{"if",		T_IF},
 	{"else",	T_ELSE},
 	{"for",		T_FOR},
@@ -111,11 +111,11 @@ static struct keyword keywords[] = {
 };
 
 
-static void eatcomment(void);
-static void eatstring(int quotechar);
-static void eatline(void);
-static int eatsymbol(void);
-static int eatnumber(void);
+S_FUNC void eatcomment(void);
+S_FUNC void eatstring(int quotechar);
+S_FUNC void eatline(void);
+S_FUNC int eatsymbol(void);
+S_FUNC int eatnumber(void);
 
 
 /*
@@ -379,7 +379,7 @@ gettoken(void)
  * Continue to eat up a comment string.
  * The leading slash-asterisk has just been scanned at this point.
  */
-static void
+S_FUNC void
 eatcomment(void)
 {
 	int ch;
@@ -407,7 +407,7 @@ eatcomment(void)
  * Typically a #! will require the rest of the line to be eaten as if
  * it were a comment.
  */
-static void
+S_FUNC void
 eatline(void)
 {
 	int ch;		/* chars being eaten */
@@ -423,7 +423,7 @@ eatline(void)
  * Read in a string and add it to the literal string pool.
  * The leading single or double quote has been read in at this point.
  */
-static void
+S_FUNC void
 eatstring(int quotechar)
 {
 	register char *cp;	/* current character address */
@@ -551,14 +551,14 @@ eatstring(int quotechar)
  * If allsyms is set, keywords are not looked up and almost all chars
  * will be accepted for the symbol.  Returns the type of symbol found.
  */
-static int
+S_FUNC int
 eatsymbol(void)
 {
 	register struct keyword *kp;	/* pointer to current keyword */
 	register char *cp;		/* current character pointer */
 	int ch;				/* current character */
 	int cc;				/* character count */
-	static char buf[SYMBOLSIZE+1];	/* temporary buffer */
+	STATIC char buf[SYMBOLSIZE+1];	/* temporary buffer */
 
 	cp = buf;
 	cc = SYMBOLSIZE;
@@ -604,7 +604,7 @@ eatsymbol(void)
  * return just a period, which is used for element accesses and for
  * the old numeric value.
  */
-static int
+S_FUNC int
 eatnumber(void)
 {
 	register char *cp;	/* current character pointer */
@@ -710,30 +710,58 @@ scanerror(int skip, char *fmt, ...)
 {
 	va_list ap;
 	char *name;		/* name of file with error */
-	char buf[MAXERROR+1];
+	int len;		/* length of error msg bufer */
 
 	/* count the error */
 	errorcount++;
 
-	/* print the error message */
+	/* form the error message */
 	name = inputname();
-	if (name)
-		fprintf(stderr, "\"%s\", line %ld: ", name, linenumber());
 	va_start(ap, fmt);
-	vsnprintf(buf, MAXERROR, fmt, ap);
+	if (name) {
+		snprintf(calc_err_msg, MAXERROR, "\"%s\", line %ld: ",
+			 name, linenumber());
+		calc_err_msg[MAXERROR] = '\0';	/* firewall */
+		len = strlen(calc_err_msg);
+		if (len < MAXERROR) {
+			vsnprintf(calc_err_msg+len, MAXERROR-len, fmt, ap);
+		}
+	} else {
+		vsnprintf(calc_err_msg, MAXERROR, fmt, ap);
+	}
 	va_end(ap);
-	buf[MAXERROR] = '\0';
-	fprintf(stderr, "%s\n", buf);
+	calc_err_msg[MAXERROR] = '\0';
+
+	/* print error message if allowed */
+	if (calc_print_scanerr_msg != 0) {
+		fprintf(stderr, "%s\n\n", calc_err_msg);
+	}
 
 	/* bail out if continuation not permitted */
-	if ((!c_flag && !stoponerror) || stoponerror > 0)
-		longjmp(jmpbuf, 1);
+	if ((!c_flag && !stoponerror) || stoponerror > 0) {
+		if (calc_use_scanerr_jmpbuf != 0) {
+			longjmp(calc_scanerr_jmpbuf, 60);
+			/*NOTREACHED*/
+		} else {
+			fprintf(stderr,
+			  "calc_scanerr_jmpbuf not setup, exiting code 60\n");
+			libcalc_call_me_last();
+			exit(60);
+		}
+	}
 
 	/* bail out if too many errors */
 	if (conf->maxscancount > 0 && errorcount > conf->maxscancount) {
-		fputs("Too many scan errors, compilation aborted.\n", stderr);
-		longjmp(jmpbuf, 1);
-		/*NOTREACHED*/
+		fprintf(stderr, "Too many scan errors, compilation aborted.\n");
+		if (calc_use_scanerr_jmpbuf != 0) {
+			longjmp(calc_scanerr_jmpbuf, 61);
+			/*NOTREACHED*/
+		} else {
+			fprintf(stderr,
+			  "calc_scanerr_jmpbuf not ready: exit 61\n");
+			libcalc_call_me_last();
+			exit(61);
+		}
 	}
 
 	/* post-error report processing */
@@ -755,7 +783,12 @@ scanerror(int skip, char *fmt, ...)
 			}
 		}
 	default:
-		fprintf(stderr, "Unknown skip token for scanerror\n");
+		snprintf(calc_err_msg, MAXERROR,
+			 "Unknown skip token for scanerror\n");
+		calc_err_msg[MAXERROR] = '\0';
+		if (calc_print_scanerr_msg != 0) {
+			fprintf(stderr, "%s\n\n", calc_err_msg);
+		}
 		/* fall into semicolon case */
 		/*FALLTHRU*/
 	case T_SEMICOLON:
@@ -782,14 +815,32 @@ warning(char *fmt, ...)
 {
 	va_list ap;
 	char *name;		/* name of file with error */
-	char buf[MAXERROR+1];
+	int len;		/* length of error msg bufer */
 
+	/* count this warning */
+	++calc_warn_cnt;
+
+	/* form the error message */
 	name = inputname();
-	if (name)
-		fprintf(stderr, "\"%s\", line %ld: ", name, linenumber());
 	va_start(ap, fmt);
-	vsnprintf(buf, MAXERROR, fmt, ap);
+	vsnprintf(calc_warn_msg, MAXERROR, fmt, ap);
+	if (name) {
+		snprintf(calc_warn_msg, MAXERROR, "\"%s\", line %ld: ",
+			 name, linenumber());
+		calc_warn_msg[MAXERROR] = '\0';	/* firewall */
+		len = strlen(calc_warn_msg);
+		if (len < MAXERROR) {
+			vsnprintf(calc_warn_msg+len, MAXERROR-len, fmt, ap);
+		}
+	} else {
+		vsnprintf(calc_warn_msg, MAXERROR, fmt, ap);
+	}
 	va_end(ap);
-	buf[MAXERROR] = '\0';
-	fprintf(stderr, "Warning: %s\n", buf);
+	calc_warn_msg[MAXERROR] = '\0';
+
+	/* print the warning if allowed */
+	if (calc_print_scanwarn_msg != 0) {
+		fprintf(stderr, "Warning: %s\n", calc_warn_msg);
+	}
+	return;
 }
